Description Usage Arguments Value References See Also
This functions extracts the scores of a fitted model. Arguments are passed
to the generic function estfun.
1 | get_scores(x, ...)
|
x |
a fitted model object. |
... |
arguments passed to methods. |
A data.frame containing the empirical estimating functions. Typically,
this should be an n * k matrix corresponding to n observations and k
parameters. The columns should be named as in coef or
terms, respectively.
The estimating function (or score function) for a model is the derivative of the objective function with respect to the parameter vector. The empirical estimating functions is the evaluation of the estimating function at the observed data (n observations) and the estimated parameters (of dimension k).
Zeileis, A. (2006). Object-oriented computation of sandwich estimators. Journal of Statistical Software, 16(9), 1-16. doi: 10.18637/jss.v016.i09
Zeileis, A., Köll, S., Graham, N. (2020). Various versatile variances: An object- oriented implementation of clustered covariances in R. Journal of Statistical Software, 95(1), 1-36. doi 10.18637/jss.v095.i01
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.